ljDates = new Object();
ljDelete = new Object();
LiveJournal = window.arguments[0];
ljPost = window.arguments[1];

const historybundle = document.getElementById("historybundle");
var commonbundle = document.getElementById("commonbundle");

function Init() {
	// Initial function, sets up calendar.
	// In: Nothing.
	// Out: Nothing.
	document.getElementById("progressbar").mode = "undetermined";
	document.getElementById("calendar").addEventListener('monthchange', ljDates.monthChanged, true);
	ljDates.calendar = new Date();
	ljDates.dayClicked(ljDates.calendar);
	// Sends a call to the server to get a list of the days that have posts on them.
	// In: The challenge issued by the server.
	// Out: Nothing.
	ljDates.httpreq = new LiveJournal.LJHttpRequest(LiveJournal.posturl);
	ljDates.httpreq.onload = ljDates.datesHandler;
	var params = new Object();
	params.user = LiveJournal.username.toLowerCase();
	
	if (LiveJournal.username != ljPost.usejournal) {
		params.usejournal = ljPost.usejournal;
	}
	
	var body = "mode=getdaycounts";
	body += LiveJournal.makeParams(params);

	ljDates.httpreq.send(body);
}
ljDates.monthChanged = function(event) {
	var month = parseInt(document.getAnonymousElementByAttribute(event.target, "anonid", "monthlabeldeck").selectedIndex, 10);;
	var year = document.getAnonymousElementByAttribute(event.target, "anonid", "yearlabel").getAttribute("value");
	ljDates.makeBoldDays(year, month + 1);
}
ljDates.dayClicked = function(dateobj) {
	ljDates.calendar = dateobj;
	var eventlist = document.getElementById("entrieslist");
	while (eventlist.childNodes.length > 2) {
		eventlist.removeChild(eventlist.lastChild);
	}
	eventlist.appendChild(document.createElement("listitem"));
	eventlist.lastChild.setAttribute("label", commonbundle.getString("Loading"));
	document.getElementById("progressdeck").selectedIndex = 0;
	ljEvents.getEvents();
}

ljDates.datesHandler = function() {
	// This gets hit as the response from the server when asked for a challenge. The code should be pretty self-explanatory.
	var result = LiveJournal.responseArray(ljDates.httpreq.request.responseText);
	if (LiveJournal.getResponseData("success", result) == "OK") {
		ljDates.dates = result;
		var now = new Date();
		ljDates.makeBoldDays(now.getFullYear(), now.getMonth() + 1, ljDates.dates);
	} else {
		var errmsg = LiveJournal.getResponseData("errmsg", result);
		if (errmsg) {
			alert(commonbundle.getString("ErrorRequest") + " " + errmsg);
		} else {
			alert(commonbundle.getString("ErrorRequest") + " " + ljDates.httpreq.request.responseText);
		}
	}
}

ljDates.makeBoldDays = function(year, month) {
	// Makes the days with posts bolded.
	// In: The year to look up, the month to look up. Each day in the month is checked.
	// Out: Nothing.
	dump(year + "/" + month + "\n");
	var cal = document.getElementById("calendar");
	var datebox = document.getAnonymousElementByAttribute(cal, "anonid", "datebox");
	for (var i = 0; i < datebox.childNodes.length; i++) {
		var row = datebox.childNodes[i];
		for (var j = 0; j < row.childNodes.length; j++) {
			var box = row.childNodes[j];
			if (box.getAttribute("role") == "gridcell") {
				var day = box.getAttribute("value");
				box.removeAttribute("style");
				box.removeAttribute("tooltiptext");
				if ((day.length > 0) && (!isNaN(day))) {
					var datestring = year + "-" + ZeroFix(month) + "-" + ZeroFix(day);
					var postcount = parseInt(LiveJournal.getResponseData(datestring, this.dates), 10);
					if (postcount > 0) {
						box.setAttribute("style", "font-weight: bold;");
						box.setAttribute("tooltiptext", historybundle.getString("PostsThisDay") + " " + postcount);
					}
				}
			}
		}
	}
	window.sizeToContent();
}

function FixClock(time) {
	// This formats LiveJournal's crazy date format into something nice looking.
	// In: Crazily formatted LJ date string.
	// Out: 12-hour time string with "am" or "pm".
	var clockarray = time.split(":");
	var hour = clockarray[0];
	var minute = clockarray[1];
	var ampm = " am";
	hour = parseInt(hour.slice(hour.lastIndexOf(" ")),10);
	if (hour > 11) {
		ampm = " pm";
		hour = hour - 12;
	}
	if (hour == 0) {
		hour = 12;
	}
	return hour + ":" + minute + ampm;
}

function ViewPost(postnode) {
	// Opens the browser to the currently selected post in the history window.
	// In: The XUL node of the selected post.
	// Out: Nothing.
	if (postnode) {
		var domain = FindDomain(LiveJournal.posturl);
		var postsplit = postnode.value.split("|");
		var itemid = postsplit[0];
		var anum = postsplit[1];
		var username;
		if (LiveJournal.username != ljPost.usejournal) {
			username = ljPost.usejournal;
		} else {
			username = LiveJournal.username;
		}
		var urlstring = domain + "users/" + username + "/" + ((parseInt(itemid, 10) * 256) + parseInt(anum, 10)) + ".html";
		OpenURLInBrowser(urlstring);
	}
}


function EditPost(postnode) {
	// Loads an edit window for the selected post.
	// In: Node of the selected post.
	// Out: Nothing.
	if (postnode) {
		var itemid = parseInt(postnode.value.split("|")[0], 10);
		var windowid = "dsedit" + itemid;
		var windowwatcher = Components.classes["@mozilla.org/embedcomp/window-watcher;1"].getService(Components.interfaces.nsIWindowWatcher);
		var editwindow = windowwatcher.getWindowByName(windowid, null);
		if (editwindow) {
			editwindow.focus();
		} else {
			window.openDialog("livejournal.xul",windowid,"chrome,resizable,titlebar,dependent,dialog=no", LiveJournal, itemid, ljPost.usejournal);
		}
	}
}

function DeletePost(postnode) {
	// Deletes the selected post.
	// In: Node of the selected post.
	// Nothing.
	if (postnode) {
		if (confirm(commonbundle.getString("SureToDelete"))) {
			document.getElementById("progressdeck").selectedIndex = 0;
			ljDelete.itemid = postnode.value.split("|")[0];
			ljDelete.deletePost();
		}
	}
}

ljDelete.deletePost = function() {
	// Sends request to delete post.
	// In: Challenge string issued from the server.
	// Out: Nothing.
	this.httpreq = new LiveJournal.LJHttpRequest(LiveJournal.posturl);
	this.httpreq.onload = this.deletionHandler;
	var params = new Object();
	
	params.user = LiveJournal.username.toLowerCase();

	
	if (LiveJournal.username != ljPost.usejournal) {
		params.usejournal = ljPost.usejournal;
	}

	params.subject = "";
	params.lineendings = "unix";
	params.event = "";
	params.year = 1;
	params.month = 1;
	params.day = 1;
	params.hour = 1;
	params.minute = 1;
	params.itemid = this.itemid;

	var body = "mode=editevent";
	body += LiveJournal.makeParams(params);
	
	this.httpreq.send(body);
}

ljDelete.deletionHandler = function() {
	// This gets hit as the response from the server when asked for a challenge. The code should be pretty self-explanatory.
	var result = LiveJournal.responseArray(ljDelete.httpreq.request.responseText);
	if (LiveJournal.getResponseData("success", result) == "OK") {
		document.getElementById("progressdeck").selectedIndex = 1;
		ljDates.dayClicked(ljDates.calendar);
	} else {
		var errmsg = LiveJournal.getResponseData("errmsg", result);
		if (errmsg) {
			alert(commonbundle.getString("ErrorRequest") + " " + errmsg);
		} else {
			alert(commonbundle.getString("ErrorRequest") + " " + ljDelete.httpreq.request.responseText);
		}
	}
}

